#!/usr/bin/env python3

# The code in this file is released under the Creative Commons CC0 license,
# i.e., for unrestricted use and without any warranty,
# see the file license_CC0.txt or https://creativecommons.org/publicdomain/zero/1.0/

import matplotlib
import matplotlib.pyplot as plt
from scipy.stats import pearsonr
import numpy as np


def anscombeValues():
    # values from F. J. Anscombe: Graphs in Statistcal Analysis, The American Statistician 27(1), 1973, p. 17–21
    x_0 = [10,  8, 13,  9, 11, 14,  6,  4, 12,  7,  5]
    x_1 = [10,  8, 13,  9, 11, 14,  6,  4, 12,  7,  5]
    x_2 = [10,  8, 13,  9, 11, 14,  6,  4, 12,  7,  5]
    x_3 = [ 8,  8,  8,  8,  8,  8,  8, 19,  8,  8,  8]

    y_0 = [ 8.04,  6.95,  7.58,  8.81,  8.33,  9.96,  7.24,  4.26, 10.84,  4.82,  5.68]
    y_1 = [ 9.14,  8.14,  8.74,  8.77,  9.26,  8.10,  6.13,  3.10,  9.13,  7.26,  4.74]
    y_2 = [ 7.46,  6.77, 12.74,  7.11,  7.81,  8.84,  6.08,  5.39,  8.15,  6.42,  5.73]
    y_3 = [ 6.58,  5.76,  7.71,  8.84,  8.47,  7.04,  5.25, 12.50,  5.56,  7.91,  6.89]

    return [[x_0, x_1, x_2, x_3], [y_0, y_1, y_2, y_3]]


def printSummaryStatistics(x, y):
    print(np.mean(x[0]), np.mean(x[1]), np.mean(x[2]), np.mean(x[3]))
    print(np.var(x[0], ddof=1), np.var(x[1], ddof=1), np.var(x[2], ddof=1), np.var(x[3], ddof=1))
    print(np.mean(y[0]), np.mean(y[1]), np.mean(y[2]), np.mean(y[3]))
    print(np.var(y[0], ddof=1), np.var(y[1], ddof=1), np.var(y[2], ddof=1), np.var(y[3], ddof=1))
    print(pearsonr(x[0], y[0]))
    print(pearsonr(x[1], y[1]))
    print(pearsonr(x[2], y[2]))
    print(pearsonr(x[3], y[3]))


def plotValues(x, y):
    f, axarr = plt.subplots(1, 4, sharex='col', sharey='row', figsize=(7.5,2))
    matplotlib.rcParams.update({'font.size': 9})
    axarr[0].plot(x[0], y[0], 'xk', mew=1.25)
    axarr[0].set_title('A')
    axarr[1].plot(x[1], y[1], 'xk', mew=1.25)
    axarr[1].set_title('B')
    axarr[2].plot(x[2], y[2], 'xk', mew=1.25)
    axarr[2].set_title('C')
    axarr[3].plot(x[3], y[3], 'xk', mew=1.25)
    axarr[3].set_title('D')

    for i in range(4):
        r_x = [0, 20]
        r_y = [3+0.5*i for i in r_x]
        axarr[i].plot(r_x, r_y, 'k-', lw=1)
        axarr[i].set_xlim((3, 20))
        axarr[i].set_ylim((3, 14))
        axarr[i].xaxis.set_ticks(np.arange(4, 24, 8))
        axarr[i].yaxis.set_ticks(np.arange(4, 16, 4))
        plt.tight_layout()
        plt.savefig('anscombe.eps')


if __name__ == '__main__':
    x, y = anscombeValues()
    printSummaryStatistics(x,y)
    plotValues(x,y)
